# ProteinGPT
```Multimodal LLM for Protein Property Prediction and Structure Understanding```

## Paper
https://arxiv.org/abs/2408.11363


## Online Service
https://proteingpt.xyz/


## BibTex
```
@article{xiao2024proteingpt,
  title={Proteingpt: Multimodal llm for protein property prediction and structure understanding},
  author={Xiao, Yijia and Sun, Edward and Jin, Yiqiao and Wang, Qifan and Wang, Wei},
  journal={arXiv preprint arXiv:2408.11363},
  year={2024}
}
```
